@@ -8,6 +8,7 @@
 
 
 from ctypes import c_size_t, c_char_p, byref
+from typing import List, Optional
 import numpy as np
 
 from .ffi._message_types import GroupFeedback
@@ -19,14 +20,12 @@ from .type_utils import create_string_buffer_compat as create_str
 
 
 class LogFile(UnmanagedObject):
-  """
-  Represents a file which contains previously recorded group messages.
-  """
+  """Represents a file which contains previously recorded group messages."""
 
   __slots__ = ['_beginning_time', '_data', '_feedbacks_read', '_next_feedback', '_number_of_modules', '_time', '__weakref__']
 
   def __calculate_time(self):
-    np.subtract(self._next_feedback.receive_time, self._beginning_time, self._time)
+    np.subtract(self._next_feedback.receive_time, self._beginning_time, out=self._time)
 
   def __read_first_feedback(self):
     feedback = GroupFeedback(self._number_of_modules)
@@ -42,20 +41,21 @@ class LogFile(UnmanagedObject):
     self.__calculate_time()
 
   def __init__(self, internal):
-    """
-    This is created internally. Do not instantiate directly.
+    """This is created internally.
+
+    Do not instantiate directly.
     """
     super(LogFile, self).__init__(internal, on_delete=api.hebiLogFileRelease)
     self._data = None
     self._feedbacks_read = 0
-    self._number_of_modules = api.hebiLogFileGetNumberOfModules(internal)
+    self._number_of_modules: int = api.hebiLogFileGetNumberOfModules(internal)
     if self._number_of_modules < 1:
       raise RuntimeError('Log file is corrupt')
 
     self.__read_first_feedback()
 
   def load(self, filter={}):
-    data = []
+    data: List[GroupFeedback] = []
     allowed_time = None
     if 'time' in filter:
       allowed_time = filter['time']
@@ -69,8 +69,8 @@ class LogFile(UnmanagedObject):
 
   @property
   def feedback_iterate(self):
-    """
-    Retrieves an iterator over feedback from the LogFile, sequentially in order from the beginning of the file.
+    """Retrieves an iterator over feedback from the LogFile, sequentially in
+    order from the beginning of the file.
 
     Note: The object returned from this method is only valid for the duration of the enclosing LogFile (`self`).
     If one attempts to use this iterator after the LogFile has been disposed, an exception will be raised.
@@ -107,13 +107,11 @@ class LogFile(UnmanagedObject):
     """
     return self._number_of_modules
 
-  def get_next_feedback(self, reuse_fbk=None):
-    """
-    Retrieves the next group feedback from the log file, if any exists.
-    This function acts as a forward sequential iterator over the data
-    in the file. Each subsequent call to this function moves farther
-    into the file. When the end of the file is reached, all subsequent calls
-    to this function returns ``None``
+  def get_next_feedback(self, reuse_fbk: Optional[GroupFeedback]=None):
+    """Retrieves the next group feedback from the log file, if any exists. This
+    function acts as a forward sequential iterator over the data in the file.
+    Each subsequent call to this function moves farther into the file. When the
+    end of the file is reached, all subsequent calls to this function raise 'StopIteration'
 
     **Warning:** any preexisting data in the provided Feedback object is erased.
 
@@ -125,13 +123,12 @@ class LogFile(UnmanagedObject):
                       fewer heap allocations.
 
     :return: The most recent feedback, provided one is available.
-             ``None`` is returned if there is no available feedback.
     :rtype:  TimedGroupFeedback
     """
     next_fbk = self._next_feedback
 
     if next_fbk is None:
-      return None
+      raise StopIteration
 
     t = self._time.copy()
     if reuse_fbk is not None:
@@ -150,13 +147,11 @@ class LogFile(UnmanagedObject):
 
 
 class LogFileFeedbackIterator(object):
-  """
-  Iterator for feedback in a log file
-  """
+  """Iterator for feedback in a log file."""
 
   __slots__ = ['_current_feedback', '_log_file']
 
-  def __init__(self, logfile):
+  def __init__(self, logfile: LogFile):
     self._log_file = WeakReferenceContainer(logfile)
     self._current_feedback = GroupFeedback(logfile.number_of_modules)
     self.__get_next()
@@ -180,9 +175,10 @@ class LogFileFeedbackIterator(object):
 
 
 class TimedGroupFeedback(GroupFeedback):
-  """
-  A feedback object with a time field. Represents feedback returned
-  from a log file. This class inherits all fields and functionality from :class:`~hebi.GroupFeedback`.
+  """A feedback object with a time field.
+
+  Represents feedback returned from a log file. This class inherits all
+  fields and functionality from :class:`~hebi.GroupFeedback`.
   """
 
   __slots__ = ['_time']
