@@ -1,15 +1,19 @@
-def parse_version(s):
+from os.path import join, dirname
+from typing import Any, List, Optional
+
+
+def parse_version(s: str):
   split = s.split('.')
-  if len(split) > 3:
-    raise ValueError("Period characters are not allowed in the suffix portion of the version string `{0}`".format(s))
-  elif len(split) < 3:
+  #if len(split) > 3:
+  #  raise ValueError("Period characters are not allowed in the suffix portion of the version string `{0}`".format(s))
+  if len(split) < 3:
     raise ValueError("Malformed version string `{0}`".format(s))
 
   import re
   r = re.compile(r"^(\d+)([a-zA-Z_0-9-]+)?$")
   patch_str = split[2]
   patch_parts = r.split(patch_str)
-  parts = []
+  parts: List[str] = []
   for entry in patch_parts:
     if entry != '':
       parts.append(entry)
@@ -22,14 +26,14 @@ def parse_version(s):
 
 
 class Version(object):
-  def __init__(self, maj, min, rev, suffix=None):
-    """
-    Suffix string must only contain the following:
+  def __init__(self, maj: int, min: int, rev: int, suffix: Optional[str]=None):
+    """Suffix string must only contain the following:
+
       * Underscore
       * Hyphen
       * alphabetical character (lower or uppercase) as determined by `[a-zA-Z]
-      * numbers as determined by `[0-9]` or `\d`
-    
+      * numbers as determined by `[0-9]` or `\\d`
+
     Note that periods (`.`) are not allowed in the suffix.
     """
     self._major_version = maj
@@ -43,29 +47,32 @@ class Version(object):
   def __repr__(self):
     return 'Version(major: {0}, minor: {1}, patch: {2}, suffix: {3})'.format(self.major_version, self.minor_version, self.patch_version, self.suffix)
 
-  def __eq__(self, o):
+  def __eq__(self, o: Any) -> bool:
     if isinstance(o, Version):
       thiz_suffix = self._suffix or ''
       o_suffix = o._suffix or ''
-      return o.major_version == self.major_version and \
-      o.minor_version == self.minor_version and \
-      o.patch_version == self.patch_version and \
-      thiz_suffix == o_suffix
+      ret = o.major_version == self.major_version and \
+            o.minor_version == self.minor_version and \
+            o.patch_version == self.patch_version and \
+            thiz_suffix == o_suffix
+      return ret
+    elif isinstance(o, str):
+      return parse_version(o) == self
     else:
-      return self == parse_version(o)
+      return False
 
-  def __ne__(self, o):
+  def __ne__(self, o: Any) -> bool:
     if isinstance(o, Version):
       thiz_suffix = self._suffix or ''
       o_suffix = o._suffix or ''
       return o.major_version != self.major_version or \
-      o.minor_version != self.minor_version or \
-      o.patch_version != self.patch_version or \
-      thiz_suffix != o_suffix
+          o.minor_version != self.minor_version or \
+          o.patch_version != self.patch_version or \
+          thiz_suffix != o_suffix
     else:
       return self != parse_version(o)
 
-  def __gt__(self, o):
+  def __gt__(self, o: Any) -> bool:
     if isinstance(o, Version):
       if self.major_version > o.major_version:
         return True
@@ -82,10 +89,12 @@ class Version(object):
       thiz_suffix = self._suffix or ''
       o_suffix = o._suffix or ''
       return thiz_suffix > o_suffix
-    else:
+    elif isinstance(o, str):
       return self > parse_version(o)
+    else:
+      raise TypeError()
 
-  def __lt__(self, o):
+  def __lt__(self, o: Any) -> bool:
     if isinstance(o, Version):
       if self.major_version < o.major_version:
         return True
@@ -102,8 +111,10 @@ class Version(object):
       thiz_suffix = self._suffix or ''
       o_suffix = o._suffix or ''
       return thiz_suffix < o_suffix
-    else:
+    elif isinstance(o, str):
       return self < parse_version(o)
+    else:
+      raise TypeError()
 
   @property
   def major_version(self):
@@ -120,15 +131,16 @@ class Version(object):
   @property
   def suffix(self):
     return self._suffix
-  
+
+
 
 
 def py_version():
-  return parse_version("2.5.0")
+  return parse_version("2.6.0")
 
 
 def min_c_api_version():
-  return parse_version("2.1.0")
+  return parse_version("2.3.0")
 
 
 def loaded_c_api_version():
@@ -138,6 +150,7 @@ def loaded_c_api_version():
 
 if __name__ == "__main__":
   import argparse
+
   def __disp(txt, vfunc):
     print('{0}: {1}'.format(txt, vfunc()))
 
